/*
Copyright 2020 the Velero contributors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package builder

import (
	corev1api "k8s.io/api/core/v1"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
)

// NodeBuilder builds Node objects.
type NodeBuilder struct {
	object *corev1api.Node
}

// ForNode is the constructor for a NodeBuilder.
func ForNode(name string) *NodeBuilder {
	return &NodeBuilder{
		object: &corev1api.Node{
			TypeMeta: metav1.TypeMeta{
				APIVersion: corev1api.SchemeGroupVersion.String(),
				Kind:       "Node",
			},
			ObjectMeta: metav1.ObjectMeta{
				Name: name,
			},
		},
	}
}

func (b *NodeBuilder) Labels(labels map[string]string) *NodeBuilder {
	b.object.Labels = labels
	return b
}

// Result returns the built Node.
func (b *NodeBuilder) Result() *corev1api.Node {
	return b.object
}
